For module_api sample, use vcpy_kernel.cu to generate ptx file for NV path.

Change-Id: Id0033678834288c4eaa56b12e7d447119be99deb
This commit is contained in:
pensun
2016-09-03 21:06:58 -05:00
parent 3c90766c70
commit 793dc2bce0
2 changed files with 8 additions and 2 deletions
+2 -2
View File
@@ -21,8 +21,8 @@ endif
ifeq (${HIP_PLATFORM}, nvcc)
vcpy_kernel.compile: vcpy_kernel.cpp
$(HIPCC) --genco vcpy_kernel.cpp -o vcpy_kernel.ptx
vcpy_kernel.compile: vcpy_kernel.cu
$(HIPCC) --genco vcpy_kernel.cu -o vcpy_kernel.ptx
clean:
rm -f *.ptx *.out
@@ -0,0 +1,6 @@
extern "C" __global__ void hello_world(float *a, float *b)
{
int tx = threadIdx.x;
b[tx] = a[tx];
}